==> nextcloud-29.0.12.tgz: nextcloud/apps/weather_status/l10n/bg.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Неизвестен адрес",
    "No result." : "Няма резултат.",
    "Malformed JSON data." : "Неправилно оформени JSON данни.",
    "Error" : "Грешка",
    "Weather status" : "Метеорологично състояние",
    "Weather status in your dashboard" : "Метеорологично състояние във вашето табло",
    "Detect location" : "Откриване на местоположение",
    "Set custom address" : "Задаване на персонализиран адрес",
    "Favorites" : "Любими",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} по късно днес небето ще е ясно",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ясно",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} по късно днес ще е облачно",
    "{temperature} {unit} cloudy" : "{temperature} {unit} облачно",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} по-късно днес времето ще е хубаво",
    "{temperature} {unit} fair weather" : "{temperature} {unit} хубаво време",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} по късно днес ще има частична облачност",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} частична облачност",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} по късно днес ще е мъгливо",
    "{temperature} {unit} foggy" : "{temperature} {unit} мъгливо",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} по късно днес ще има слаби валежи",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} слаби валежи",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} по късно днес ще има валежи",
    "{temperature} {unit} rainfall" : "{temperature} {unit} дъжд",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} по късно днес ще има силни валежи",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} силни валежи",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} по късно днес ще има превалявания от дъжд",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} превалявания от дъжд",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} по късно днес ще има леки превалявания от дъжд",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} леки превалявания от дъжд",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} по късно днес ще има обилни превалявания от дъжд",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} обилни превалявания от дъжд",
    "More weather for {adr}" : "Още за времето за {adr}",
    "Loading weather" : "Зареждане на времето",
    "Set location for weather" : "Задаване на местоположение за метеорологично време",
    "Remove from favorites" : "Премахни от любимите",
    "Add as favorite" : "Добавяне към любими",
    "You are not logged in." : "Не сте се вписали.",
    "There was an error getting the weather status information." : "Възникна грешка при получаването на информацията за състоянието на времето.",
    "No weather information found" : "Няма намерена информация за времето",
    "Location not found" : "Местоположението не е намерено",
    "There was an error setting the location address." : "Възникна грешка при задаване на адрес на местоположението.",
    "There was an error setting the location." : "Възникна грешка при задаване на местоположението.",
    "There was an error saving the mode." : "Възникна грешка при запазването на режима.",
    "There was an error using personal address." : "Възникна грешка при използването на личния адрес."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/weather_status/l10n/bg.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Неизвестен адрес",
    "No result." : "Няма резултат.",
    "Malformed JSON data." : "Неправилно оформени JSON данни.",
    "Error" : "Грешка",
    "Weather status" : "Метеорологично състояние",
    "Weather status in your dashboard" : "Метеорологично състояние във вашето табло",
    "Detect location" : "Откриване на местоположение",
    "Set custom address" : "Задаване на персонализиран адрес",
    "Favorites" : "Любими",
    "{temperature} {unit} clear sky later today" : "{temperature} {unit} по късно днес небето ще е ясно",
    "{temperature} {unit} clear sky" : "{temperature} {unit} ясно",
    "{temperature} {unit} cloudy later today" : "{temperature} {unit} по късно днес ще е облачно",
    "{temperature} {unit} cloudy" : "{temperature} {unit} облачно",
    "{temperature} {unit} fair weather later today" : "{temperature} {unit} по-късно днес времето ще е хубаво",
    "{temperature} {unit} fair weather" : "{temperature} {unit} хубаво време",
    "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} по късно днес ще има частична облачност",
    "{temperature} {unit} partly cloudy" : "{temperature} {unit} частична облачност",
    "{temperature} {unit} foggy later today" : "{temperature} {unit} по късно днес ще е мъгливо",
    "{temperature} {unit} foggy" : "{temperature} {unit} мъгливо",
    "{temperature} {unit} light rainfall later today" : "{temperature} {unit} по късно днес ще има слаби валежи",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} слаби валежи",
    "{temperature} {unit} rainfall later today" : "{temperature} {unit} по късно днес ще има валежи",
    "{temperature} {unit} rainfall" : "{temperature} {unit} дъжд",
    "{temperature} {unit} heavy rainfall later today" : "{temperature} {unit} по късно днес ще има силни валежи",
    "{temperature} {unit} heavy rainfall" : "{temperature} {unit} силни валежи",
    "{temperature} {unit} rainfall showers later today" : "{temperature} {unit} по късно днес ще има превалявания от дъжд",
    "{temperature} {unit} rainfall showers" : "{temperature} {unit} превалявания от дъжд",
    "{temperature} {unit} light rainfall showers later today" : "{temperature} {unit} по късно днес ще има леки превалявания от дъжд",
    "{temperature} {unit} light rainfall showers" : "{temperature} {unit} леки превалявания от дъжд",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature} {unit} по късно днес ще има обилни превалявания от дъжд",
    "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} обилни превалявания от дъжд",
    "More weather for {adr}" : "Още за времето за {adr}",
    "Loading weather" : "Зареждане на времето",
    "Set location for weather" : "Задаване на местоположение за метеорологично време",
    "Remove from favorites" : "Премахни от любимите",
    "Add as favorite" : "Добавяне към любими",
    "You are not logged in." : "Не сте се вписали.",
    "There was an error getting the weather status information." : "Възникна грешка при получаването на информацията за състоянието на времето.",
    "No weather information found" : "Няма намерена информация за времето",
    "Location not found" : "Местоположението не е намерено",
    "There was an error setting the location address." : "Възникна грешка при задаване на адрес на местоположението.",
    "There was an error setting the location." : "Възникна грешка при задаване на местоположението.",
    "There was an error saving the mode." : "Възникна грешка при запазването на режима.",
    "There was an error using personal address." : "Възникна грешка при използването на личния адрес.",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Метеорологичното състояние, интегрирано в приложението Dashboard.\n    Позицията на потребителя може да се определя автоматично или ръчно. След което се показва прогноза за 6 часа.\n    Това състояние може да бъде интегрирано и на други места като приложението Календар."
},
"nplurals=2; plural=(n != 1);");
